package edu.nyu.sps.viewpropertyanimator;

import android.content.Context;
import android.graphics.Color;
import android.graphics.Point;
import android.graphics.Rect;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewPropertyAnimator;
import android.view.animation.AccelerateDecelerateInterpolator;
import android.widget.RelativeLayout;


public class BackgroundView extends RelativeLayout {
    private LittleView littleView = new LittleView(getContext());

    public BackgroundView(Context context) {
        super(context);
        setBackgroundColor(Color.WHITE);
        addView(littleView);

        setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, final MotionEvent motionEvent) {
                switch (motionEvent.getAction()) {
                    case MotionEvent.ACTION_DOWN:
                        ViewPropertyAnimator viewPropertyAnimator = littleView.animate();
                        viewPropertyAnimator.setDuration(1000L);    //milliseconds
                        viewPropertyAnimator.setInterpolator(new AccelerateDecelerateInterpolator()); //the default
                        //If we put the upper left corner of littleView at this location,
                        //the center of the littleView will be where the finger touched.
                        float newX = motionEvent.getX() - littleView.getWidth() / 2f;
                        float newY = motionEvent.getY() - littleView.getHeight() / 2f;
                        //Start two animations simultaneously.
                        viewPropertyAnimator.x(newX);
                        viewPropertyAnimator.y(newY);
                        return true;

                    default:
                        return false;
                }
            }
        });
    }

    @Override
    protected void onLayout(boolean changed, int left, int top, int right, int bottom) {
        super.onLayout(changed, left, top, right, bottom);
        Rect rect = new Rect(left, top, right, bottom);
        Point center = new Point(rect.centerX(), rect.centerY());
        int radius = Math.min(getWidth(), getHeight()) / 10;    //of circle in LittleView

        //Center the LittleView in this BackgroundView.
        //Calls the onLayout method of the LittleView.
        //left, top, right, bottom
        littleView.layout(
                center.x - radius,
                center.y - radius,
                center.x + radius,
                center.y + radius);
    }

    //Don't override onDraw method.

}
